# mcp-vision-stat

A Model Context Protocol server providing tools to fetch statistics from video intelligent operation platform powered by E20

## tools

- get_event_statistic
- get_top10_machines
- get_industry_statistic
- get_manufacturer_statistic
- get_province_statistic
- get_region_statistic
